OrbitCam

Struct OrbitCam 

pub struct OrbitCam {
Show 34 fields pub focus: Vec3, pub radius: Option<f32>, pub yaw: Option<f32>, pub pitch: Option<f32>, pub target_focus: Vec3, pub target_yaw: f32, pub target_pitch: f32, pub target_radius: f32, pub yaw_upper_limit: Option<f32>, pub yaw_lower_limit: Option<f32>, pub pitch_upper_limit: Option<f32>, pub pitch_lower_limit: Option<f32>, pub focus_bounds_origin: Vec3, pub focus_bounds_shape: Option<FocusBoundsShape>, pub zoom_upper_limit: Option<f32>, pub zoom_lower_limit: f32, pub orbit_sensitivity: f32, pub orbit_smoothness: f32, pub pan_sensitivity: f32, pub pan_smoothness: f32, pub zoom_sensitivity: f32, pub zoom_smoothness: f32, pub button_orbit: MouseButton, pub button_pan: MouseButton, pub button_zoom: Option<MouseButton>, pub button_zoom_axis: ButtonZoomAxis, pub modifier_orbit: Option<KeyCode>, pub modifier_pan: Option<KeyCode>, pub input_control: Option<InputControl>, pub upside_down_policy: UpsideDownPolicy, pub initialization: InitializationState, pub force_update: ForceUpdate, pub axis: [Vec3; 3], pub time_source: TimeSource,
}
Tags an entity as capable of panning and orbiting.

Provides a way to configure the camera’s behaviour and controls.

Example

fn setup(mut commands: Commands) {
    commands.spawn((
        Transform::from_translation(Vec3::new(0.0, 1.5, 5.0)),
        OrbitCam::default(),
    ));
}

Fields

focus: Vec3

The point to orbit around, and what the camera looks at. Updated automatically. If you want to change the focus programmatically after initialization, set target_focus instead. Defaults to Vec3::ZERO.

radius: Option<f32>

The radius of the orbit, or the distance from the focus point. For orthographic projection, this is ignored, and the projection’s scale is used instead. If set to None, it will be calculated from the camera’s current position during initialization. Automatically updated. Defaults to None.

yaw: Option<f32>

Rotation in radians around the global Y axis (longitudinal). Updated automatically. If both yaw and pitch are 0.0, then the camera will be looking forward, i.e. in the Vec3::NEG_Z direction, with up being Vec3::Y. If set to None, it will be calculated from the camera’s current position during initialization. You should not update this after initialization - use target_yaw instead. Defaults to None.

pitch: Option<f32>

Rotation in radians around the local X axis (latitudinal). Updated automatically. If both yaw and pitch are 0.0, then the camera will be looking forward, i.e. in the Vec3::NEG_Z direction, with up being Vec3::Y. If set to None, it will be calculated from the camera’s current position during initialization. You should not update this after initialization - use target_pitch instead. Defaults to None.

target_focus: Vec3

The target focus point. The camera will smoothly transition to this value. Updated automatically, but you can also update it manually to control the camera independently of the mouse controls, e.g. with the keyboard. Defaults to Vec3::ZERO.

target_yaw: f32

The target yaw value. The camera will smoothly transition to this value. Updated automatically, but you can also update it manually to control the camera independently of the mouse controls, e.g. with the keyboard. Defaults to 0.0.

target_pitch: f32

The target pitch value. The camera will smoothly transition to this value Updated automatically, but you can also update it manually to control the camera independently of the mouse controls, e.g. with the keyboard. Defaults to 0.0.

target_radius: f32

The target radius value. The camera will smoothly transition to this value. Updated automatically, but you can also update it manually to control the camera independently of the mouse controls, e.g. with the keyboard. Defaults to 1.0.

yaw_upper_limit: Option<f32>

Upper limit on the yaw value, in radians. Use this to restrict the maximum rotation around the global Y axis. Defaults to None.

yaw_lower_limit: Option<f32>

Lower limit on the yaw value, in radians. Use this to restrict the maximum rotation around the global Y axis. Defaults to None.

pitch_upper_limit: Option<f32>

Upper limit on the pitch value, in radians. Use this to restrict the maximum rotation around the local X axis. Defaults to None.

pitch_lower_limit: Option<f32>

Lower limit on the pitch value, in radians. Use this to restrict the maximum rotation around the local X axis. Defaults to None.

focus_bounds_origin: Vec3

The origin for a shape to restrict the cameras focus position. Defaults to Vec3::ZERO.

focus_bounds_shape: Option<FocusBoundsShape>

The shape (Sphere or Cuboid) that the focus is restricted by. Centered on the focus_bounds_origin. Defaults to None.

zoom_upper_limit: Option<f32>

Upper limit on the zoom. This applies to radius, in the case of using a perspective camera, or the projection’s scale in the case of using an orthographic camera. Defaults to None.

zoom_lower_limit: f32

Lower limit on the zoom. This applies to radius, in the case of using a perspective camera, or the projection’s scale in the case of using an orthographic camera. Should always be >0 otherwise you’ll get stuck at 0. Defaults to 1e-7.

orbit_sensitivity: f32

The sensitivity of the orbiting motion. A value of 0.0 disables orbiting. Defaults to 1.0.

orbit_smoothness: f32

How much smoothing is applied to the orbit motion. A value of 0.0 disables smoothing, so there’s a 1:1 mapping of input to camera position. A value of 1.0 is infinite smoothing. Defaults to 0.8.

pan_sensitivity: f32

The sensitivity of the panning motion. A value of 0.0 disables panning. Defaults to 1.0.

pan_smoothness: f32

How much smoothing is applied to the panning motion. A value of 0.0 disables smoothing, so there’s a 1:1 mapping of input to camera position. A value of 1.0 is infinite smoothing. Defaults to 0.6.

zoom_sensitivity: f32

The sensitivity of moving the camera closer or further way using the scroll wheel. A value of 0.0 disables zooming. Defaults to 1.0.

zoom_smoothness: f32

How much smoothing is applied to the zoom motion. A value of 0.0 disables smoothing, so there’s a 1:1 mapping of input to camera position. A value of 1.0 is infinite smoothing. Defaults to 0.8. Note that this setting does not apply to pixel-based scroll events, as they are typically already smooth. It only applies to line-based scroll events.

button_orbit: MouseButton

Button used to orbit the camera. Defaults to Button::Left.

button_pan: MouseButton

Button used to pan the camera. Defaults to Button::Right.

button_zoom: Option<MouseButton>

Button used to zoom the camera, by holding it down and moving the mouse forward and back. Defaults to None.

button_zoom_axis: ButtonZoomAxis

Which axis should zoom the camera when using button_zoom. Defaults to ButtonZoomAxis::Y.

modifier_orbit: Option<KeyCode>

Key that must be pressed for button_orbit to work. Defaults to None (no modifier).

modifier_pan: Option<KeyCode>

Key that must be pressed for button_pan to work. Defaults to None (no modifier).

input_control: Option<InputControl>

Interactive input configuration. Set to None to disable all user input for this camera. Defaults to Some(InputControl::default()).

upside_down_policy: UpsideDownPolicy

Whether to allow the camera to go upside down. Defaults to UpsideDownPolicy::Prevent.

initialization: InitializationState

Whether OrbitCam has been initialized with the initial config. Set to InitializationState::Complete if you want the camera to smoothly animate to its initial position. Defaults to InitializationState::Pending.

force_update: ForceUpdate

Whether to update the camera’s transform regardless of whether there are any changes/input. Set to ForceUpdate::Pending if you want to modify values directly. This will be automatically set back to ForceUpdate::Idle after one frame. Defaults to ForceUpdate::Idle.

axis: [Vec3; 3]

Axis order definition. This can be used to e.g. define a different default up direction. The default up is Y, but if you want the camera rotated. The axis can be switched. Defaults to [Vec3::X, Vec3::Y, Vec3::Z].

time_source: TimeSource

Which time source drives camera smoothing. Defaults to TimeSource::Virtual.